apiVersion: v1
kind: Pod
spec:
  hostNetwork: True
  containers:
    - name: nova-api
      image: "{{ nova_api_image_full }}"
      volumeMounts:
        - mountPath: {{ container_config_directory }}
          name: nova-api-config
        - mountPath: /etc/localtime
          name: etc-localtime
        - mountPath: /lib/modules
          name: lib-modules
        - mountPath: /var/log/kolla
          name: kolla-logs
      env:
        - name: KOLLA_CONFIG_STRATEGY
          value: {{ config_strategy }}
    - name: nova-conductor
      image: "{{ nova_conductor_image_full }}"
      volumeMounts:
        - mountPath: {{ container_config_directory }}
          name: nova-conductor-config
        - mountPath: /etc/localtime
          name: etc-localtime
        - mountPath: /var/log/kolla
          name: kolla-logs
      env:
        - name: KOLLA_CONFIG_STRATEGY
          value: {{ config_strategy }}
    - name: nova-scheduler
      image: "{{ nova_scheduler_image_full }}"
      volumeMounts:
        - mountPath: {{ container_config_directory }}
          name: nova-scheduler-config
        - mountPath: /etc/localtime
          name: etc-localtime
        - mountPath: /var/log/kolla
          name: kolla-logs
      env:
        - name: KOLLA_CONFIG_STRATEGY
          value: {{ config_strategy }}
  volumes:
    - name: nova-api-config
      configMap:
        name: nova-api-configmap
    - name: nova-conductor-config
      configMap:
        name: nova-conductor-configmap
    - name: nova-scheduler-config
      configMap:
        name: nova-scheduler-configmap
    - name: etc-localtime
      hostPath:
        path: /etc/localtime
    - name: lib-modules
      hostPath:
        path: /lib/modules
    - name: kolla-logs
      emptyDir: {}
metadata:
   name: nova-control
