# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class KollaException(Exception):
    pass


class KollaDirNotFoundException(KollaException):
    pass


class KollaNotFoundException(KollaException):
    def __init__(self, message, entity='file'):
        super(KollaNotFoundException, self).__init__(
            'The %s "%s" was not found' % (entity, message))


class KollaNotSupportedException(KollaNotFoundException):
    def __init__(self, operation='update', entity='kubernetes'):
        super(KollaNotFoundException, self).__init__(
            'Operation "%s" is not supported by "%s"' % (operation, entity))
