apiVersion: batch/v1
kind: Job
spec:
  template:
    metadata:
      name: nova-compute-generate
    spec:
      hostNetwork: True
      containers:
        - name: nova-compute
          image: "{{ nova_compute_image_full }}"
          securityContext:
            privileged: true
          volumeMounts:
            - mountPath: {{ container_config_directory }}
              name: nova-compute-config
            - mountPath: /var/lib/nova/instances
              name: nova-compute-persistent-storage
            - mountPath: /etc/localtime
              name: etc-localtime
            - mountPath: /lib/modules
              name: lib-modules
            - mountPath: /run
              name: run
            - mountPath: /dev
              name: dev
            - mountPath: /sys/fs/cgroup
              name: sys-fs-cgroup
            - mountPath: /var/log/kolla
              name: kolla-logs
          env:
            - name: KOLLA_BOOTSTRAP
              value: ""
            - name: KOLLA_CONFIG_STRATEGY
              value: {{ config_strategy }}
      volumes:
        - name: nova-compute-config
          configMap:
            name: nova-compute-configmap
        - name: nova-compute-persistent-storage
          hostPath:
            path: /var/lib/nova/instances
        - name: etc-localtime
          hostPath:
            path: /etc/localtime
        - name: lib-modules
          hostPath:
            path: /lib/modules
        - name: run
          hostPath:
            path: /run
        - name: dev
          hostPath:
            path: /dev
        - name: sys-fs-cgroup
          hostPath:
            path: /sys/fs/cgroup
        - name: kolla-logs
          emptyDir: {}
      restartPolicy: OnFailure
metadata:
  name: nova-compute-bootstrap
