apiVersion: v1
kind: Pod
spec:
  hostNetwork: True
  containers:
    - image: "{{ rabbitmq_image_full }}"
      name: rabbitmq
      volumeMounts:
        - mountPath: {{ container_config_directory }}
          name: rabbitmq-config
        - mountPath: /var/lib/rabbitmq
          name: rabbitmq-persistent-storage
        - mountPath: /var/log/kolla
          name: kolla-logs
      env:
        - name: KOLLA_CONFIG_STRATEGY
          value: {{ config_strategy }}
  volumes:
    - name: rabbitmq-config
      configMap:
        name: rabbitmq-configmap
    - name: rabbitmq-persistent-storage
      hostPath:
        path: /var/lib/rabbitmq
    - name: kolla-logs
      emptyDir: {}
metadata:
   name: rabbitmq